Transformer Functions
---------------------

A collection of functions which can be referenced within the
``sklearn.preprocessing.FunctionTransformer`` transformer.

General
=======

.. automodule:: gordo.machine.model.transformer_funcs.general
    :members:
    :undoc-members:
    :show-inheritance:
